﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using CrimeStatsFinal.CityCrimeService;
using System.Data.Services.Client;
using C1.Phone.Chart;
using System.Windows.Data;

namespace CrimeStatsFinal
{
    public partial class MainPage : PhoneApplicationPage
    {
        private datagovCrimesContainer _context;
        private readonly Uri _crimesUri = new Uri("https://api.datamarket.azure.com/data.gov/Crimes/");
        private DataServiceCollection<CityCrime> _crimes;

        String _userId = "richd@componentone.com";
        const String _key = "FtsDefZvJNf0MXiTgFgxmiqGqYKkK6kkNrC3xiPCEdU=";
        
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            //add network check

            _context = new datagovCrimesContainer(_crimesUri);
            _crimes = new DataServiceCollection<CityCrime>(_context);
            var _query = from c in _context.CityCrime where c.State == "Pennsylvania" && c.City == "Pittsburgh" orderby c.Year select c;

            _context.Credentials = new NetworkCredential(_userId, _key);

            // Register for the LoadCompleted event.
            _crimes.LoadCompleted
                += new EventHandler<LoadCompletedEventArgs>(crimes_LoadCompleted);

            // Load the customers feed by executing the LINQ query.
            _crimes.LoadAsync(_query);

            
        }

        void crimes_LoadCompleted(object sender, LoadCompletedEventArgs e)
        {
            if (e.Error != null)
            {
                MessageBox.Show("Error occurred");
            }
            else
            {
                this.LayoutRoot.DataContext = _crimes;

                LoadCharts();

                c1ProgressBar1.Visibility = System.Windows.Visibility.Collapsed;
            }
        }

        void LoadCharts()
        {
            //reset and remove default data
            ResetChart(c1Chart1);
            c1Chart1.Data.ItemNameBinding = new Binding("Year");
            c1Chart1.View.AxisY.MajorUnit = 5000;
            c1Chart1.ChartType = ChartType.ColumnStacked;

            //add data series to crimeChart
            AddDataSeries(c1Chart1, "AggravatedAssault", "AggrAssault");
            AddDataSeries(c1Chart1, "Arson");
            AddDataSeries(c1Chart1, "Burglary");
            AddDataSeries(c1Chart1, "ForcibleRape");
            AddDataSeries(c1Chart1, "LarcenyTheft");
            AddDataSeries(c1Chart1, "MotorVehicleTheft", "VehicleTheft");
            AddDataSeries(c1Chart1, "MurderAndNonEgligentManslaughter", "Murder");
            AddDataSeries(c1Chart1, "PropertyCrime");
            AddDataSeries(c1Chart1, "ViolentCrime");

            //add trend total crimes
            ResetChart(populationChart);
            ResetChart(crimeChart);

            //bind ItemNames to Years
            populationChart.Data.ItemNameBinding = new Binding("Year");
            crimeChart.Data.ItemNameBinding = new Binding("Year");

            AddDataSeries(populationChart, "Population");

            //add total crimes series
            DataSeries ds = new DataSeries();
            ds.Label = "TotalCrimes";
            ds.ValuesSource = TotalCrimeData();
            crimeChart.Data.Children.Add(ds);

        }

        void ResetChart(C1Chart chart)
        {
            chart.Reset(true);
            chart.Data.Children.Clear();
        }

        void AddDataSeries(C1Chart chart, string field)
        {
            AddDataSeries(chart, field, field);
        }

        void AddDataSeries(C1Chart chart, string field, string label)
        {
            DataSeries ds = new DataSeries();
            ds.Label = label;
            ds.ValueBinding = new Binding(field);
            chart.Data.Children.Add(ds);
        }

        public List<double> TotalCrimeData()
        {

            List<double> totalCrimes = new List<double>();
            for (int i = 0; i < _crimes.Count; i++)
            {
                double d = _crimes[i].AggravatedAssault;
                d += _crimes[i].Arson;
                d += _crimes[i].Burglary;
                d += _crimes[i].ForcibleRape;
                d += _crimes[i].LarcenyTheft;
                d += _crimes[i].MotorVehicleTheft;
                d += _crimes[i].MurderAndNonEgligentManslaughter;
                d += _crimes[i].PropertyCrime;
                d += _crimes[i].Robbery;
                d += _crimes[i].ViolentCrime;
                totalCrimes.Add(d);
            }
            return totalCrimes;
        }

    }
}